==> apache-any23-2.2-src.zip: apache-any23-2.2-src/core/src/main/java/org/apache/any23/writer/RDFXMLWriterFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.any23.writer;

import java.io.OutputStream;

import org.eclipse.rdf4j.rio.RDFFormat;

/**
 * @author Peter Ansell p_ansell@yahoo.com
 * 
 */
public class RDFXMLWriterFactory implements WriterFactory {

    public static final String MIME_TYPE = RDFFormat.RDFXML.getDefaultMIMEType();
    public static final String IDENTIFIER = "rdfxml";

    /**
     * 
     */
    public RDFXMLWriterFactory() {
    }

    @Override
    public RDFFormat getRdfFormat() {
        return RDFFormat.RDFXML;
    }

    @Override
    public String getIdentifier() {
        return RDFXMLWriterFactory.IDENTIFIER;
    }

    @Override
    public String getMimeType() {
        return RDFXMLWriterFactory.MIME_TYPE;
    }

    @Override
    public FormatWriter getRdfWriter(OutputStream os) {
        return new RDFXMLWriter(os);
    }

}

==> apache-any23-2.4-src.zip: apache-any23-2.4-src/core/src/main/java/org/apache/any23/writer/RDFXMLWriterFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.any23.writer;

import java.io.OutputStream;

import org.apache.any23.configuration.Settings;

/**
 * @author Peter Ansell (p_ansell@yahoo.com)
 * @author Hans Brende (hansbrende@apache.org)
 */
public class RDFXMLWriterFactory implements TripleWriterFactory {

    public static final String MIME_TYPE = RDFXMLWriter.Internal.FORMAT.getMimeType();
    public static final String IDENTIFIER = "rdfxml";

    /**
     * 
     */
    public RDFXMLWriterFactory() {
    }

    @Override
    public TripleFormat getTripleFormat() {
        return RDFXMLWriter.Internal.FORMAT;
    }

    @Override
    public Settings getSupportedSettings() {
        return RDFXMLWriter.Internal.SUPPORTED_SETTINGS;
    }

    @Override
    public String getIdentifier() {
        return IDENTIFIER;
    }

    @Override
    public TripleHandler getTripleWriter(OutputStream os, Settings settings) {
        return new RDFXMLWriter(os, settings);
    }

}
